# analyze
aopy is a python module for neural data analysis, developed at UW in the lab of Amy Orsborn

## Installation
`pip install aolab-aopy`

## Documentation
See our [readthedocs](https://analyze.readthedocs.io/en/latest/)
